==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1DeleteOptionsFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.Long;
import java.lang.String;
import java.lang.Boolean;

public interface V1DeleteOptionsFluent<A extends V1DeleteOptionsFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public Long getGracePeriodSeconds();
    public A withGracePeriodSeconds(Long gracePeriodSeconds);
    public Boolean hasGracePeriodSeconds();
    public A withNewGracePeriodSeconds(String arg1);
    public A withNewGracePeriodSeconds(long arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public Boolean isOrphanDependents();
    public A withOrphanDependents(Boolean orphanDependents);
    public Boolean hasOrphanDependents();
    public A withNewOrphanDependents(boolean arg1);
    public A withNewOrphanDependents(String arg1);
    
/**
 * This method has been deprecated, please use method buildPreconditions instead.
 * @return The buildable object.
 */
@Deprecated public V1Preconditions getPreconditions();
    public V1Preconditions buildPreconditions();
    public A withPreconditions(V1Preconditions preconditions);
    public Boolean hasPreconditions();
    public V1DeleteOptionsFluent.PreconditionsNested<A> withNewPreconditions();
    public V1DeleteOptionsFluent.PreconditionsNested<A> withNewPreconditionsLike(V1Preconditions item);
    public V1DeleteOptionsFluent.PreconditionsNested<A> editPreconditions();
    public V1DeleteOptionsFluent.PreconditionsNested<A> editOrNewPreconditions();
    public V1DeleteOptionsFluent.PreconditionsNested<A> editOrNewPreconditionsLike(V1Preconditions item);
    public String getPropagationPolicy();
    public A withPropagationPolicy(String propagationPolicy);
    public Boolean hasPropagationPolicy();

    public interface PreconditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1PreconditionsFluent<V1DeleteOptionsFluent.PreconditionsNested<N>>{

        
    public N and();    public N endPreconditions();
}


}

==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1DeleteOptionsFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1DeleteOptionsFluent<A extends V1DeleteOptionsFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToDryRun(int index,String item);
    public A setToDryRun(int index,String item);
    public A addToDryRun(String... items);
    public A addAllToDryRun(Collection<String> items);
    public A removeFromDryRun(String... items);
    public A removeAllFromDryRun(Collection<String> items);
    public List<String> getDryRun();
    public String getDryRun(int index);
    public String getFirstDryRun();
    public String getLastDryRun();
    public String getMatchingDryRun(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withDryRun(List<String> dryRun);
    public A withDryRun(String... dryRun);
    public Boolean hasDryRun();
    public Long getGracePeriodSeconds();
    public A withGracePeriodSeconds(Long gracePeriodSeconds);
    public Boolean hasGracePeriodSeconds();
    public A withNewGracePeriodSeconds(String arg1);
    public A withNewGracePeriodSeconds(long arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public Boolean isOrphanDependents();
    public A withOrphanDependents(Boolean orphanDependents);
    public Boolean hasOrphanDependents();
    public A withNewOrphanDependents(boolean arg1);
    public A withNewOrphanDependents(String arg1);
    
/**
 * This method has been deprecated, please use method buildPreconditions instead.
 * @return The buildable object.
 */
@Deprecated public V1Preconditions getPreconditions();
    public V1Preconditions buildPreconditions();
    public A withPreconditions(V1Preconditions preconditions);
    public Boolean hasPreconditions();
    public V1DeleteOptionsFluent.PreconditionsNested<A> withNewPreconditions();
    public V1DeleteOptionsFluent.PreconditionsNested<A> withNewPreconditionsLike(V1Preconditions item);
    public V1DeleteOptionsFluent.PreconditionsNested<A> editPreconditions();
    public V1DeleteOptionsFluent.PreconditionsNested<A> editOrNewPreconditions();
    public V1DeleteOptionsFluent.PreconditionsNested<A> editOrNewPreconditionsLike(V1Preconditions item);
    public String getPropagationPolicy();
    public A withPropagationPolicy(String propagationPolicy);
    public Boolean hasPropagationPolicy();

    public interface PreconditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1PreconditionsFluent<V1DeleteOptionsFluent.PreconditionsNested<N>>{

        
    public N and();    public N endPreconditions();
}


}
